%global sum Tool to create isolated Python environments
%global desc \
virtualenv is a tool to create isolated Python environments. virtualenv \
is a successor to workingenv, and an extension of virtual-python. It is \
written by Ian Bicking, and sponsored by the Open Planning Project. It \
is licensed under an MIT-style permissive license.

Name:           python3-virtualenv
Version:        15.1.0
Release:        2%{?dist}
Summary:        %{sum}

Group:          Development/Languages
License:        MIT
URL:            https://pypi.python.org/pypi/virtualenv
Source0:        https://files.pythonhosted.org/packages/source/v/virtualenv/virtualenv-%{version}.tar.gz

# virtualenv -p "/usr/bin/python3" venv fails if there are not packages installed
# under /usr/local/lib/pythonX.Y/site-packages. Check if exec_dir exists before
# listing it's content.
Patch0: check-exec_dir.patch

BuildArch:      noarch

BuildRequires:  python%{python3_pkgversion}-devel
## Tests
#BuildRequires:  python%{python3_pkgversion}-mock
#BuildRequires:  python%{python3_pkgversion}-pytest
# Not yet packaged
#BuildRequires:  python%{python3_pkgversion}-sphinx
BuildRequires:  python-sphinx
%if 0%{?with_python3_other}
BuildRequires:  python%{python3_other_pkgversion}-devel
## Tests
#BuildRequires:  python%{python3_other_pkgversion}-mock
#BuildRequires:  python%{python3_other_pkgversion}-pytest
%endif

%description %{desc}


%package        doc
Summary:        Documentation for python virtualenv

%description    doc
Documentation for python virtualenv.

%if %{python3_pkgversion} != 3
%package -n     python%{python3_pkgversion}-virtualenv
Summary:        %{sum}

Requires:       python%{python3_pkgversion}-setuptools
Requires:       python%{python3_pkgversion}-devel
%{?python_provide:%python_provide python%{python3_pkgversion}-virtualenv}

%description -n python%{python3_pkgversion}-virtualenv %{desc}
%endif


%if 0%{?with_python3_other}
%package -n     python%{python3_other_pkgversion}-virtualenv
Summary:        %{sum}

Requires:       python%{python3_other_pkgversion}-setuptools
Requires:       python%{python3_other_pkgversion}-devel
%{?python_provide:%python_provide python%{python3_other_pkgversion}-virtualenv}

%description -n python%{python3_other_pkgversion}-virtualenv %{desc}
%endif


%prep
%setup -q -n virtualenv-%{version}
%{__sed} -i -e "1s|#!/usr/bin/env python||" virtualenv.py 

%patch0 -p1

%build
%py3_build
%py3_other_build

#{__python3} setup.py build_sphinx
%{__python2} setup.py build_sphinx
rm -f build/sphinx/html/.buildinfo


%install
%if 0%{?with_python3_other}
%py3_other_install
mv %{buildroot}/%{_bindir}/virtualenv %{buildroot}/%{_bindir}/virtualenv-%{python3_other_version}
%endif

%py3_install
# rename binaries to use python3
mv %{buildroot}/%{_bindir}/virtualenv %{buildroot}/%{_bindir}/py3-virtualenv
# The versioned 3.x script was removed from upstream. Add it back.
cp %{buildroot}/%{_bindir}/py3-virtualenv %{buildroot}/%{_bindir}/virtualenv-%{python3_version}
cp %{buildroot}/%{_bindir}/py3-virtualenv %{buildroot}/%{_bindir}/virtualenv-3


# We can't run the tests, they require network access to install pip, setuptools and wheel.
#%%check
#py.test-%{python3_version}
#%if 0%{?with_python3_other}
#py.test-%{python3_other_version}
#%endif


# Include sphinx docs on Fedora
%files doc
%doc build/sphinx/*

%files -n python%{python3_pkgversion}-virtualenv
%license LICENSE.txt
%doc docs/*rst PKG-INFO AUTHORS.txt
%{_bindir}/py3-virtualenv
%{_bindir}/virtualenv-3
%{_bindir}/virtualenv-%{python3_version}
%{python3_sitelib}/virtualenv.py
%{python3_sitelib}/virtualenv_support/
%{python3_sitelib}/virtualenv-*.egg-info
%{python3_sitelib}/__pycache__/*

%if 0%{?with_python3_other}
%files -n python%{python3_other_pkgversion}-virtualenv
%license LICENSE.txt
%doc docs/*rst PKG-INFO AUTHORS.txt
%{_bindir}/virtualenv-%{python3_other_version}
%{python3_other_sitelib}/virtualenv.py
%{python3_other_sitelib}/virtualenv_support/
%{python3_other_sitelib}/virtualenv-*.egg-info
%{python3_other_sitelib}/__pycache__/*
%endif


%changelog
* Tue Nov 14 2017 Aurelien Bompard <abompard@fedoraproject.org> - 15.1.0-2
- Build for python3_other

* Mon Aug 14 2017 Orion Poplawski <orion@cora.nwra.com> - 15.1.0-1
- Update to 15.1.0

* Fri Mar 10 2017 Orion Poplawski <orion@cora.nwra.com> - 15.0.3-1
- Initial EPEL package
